@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/clock.c,v 1.2 2000/05/28 18:29:03 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/clock.c,v 1.3 2001/06/15 16:36:36 werner Exp $
  *
  * Clock Module
  *
@@ -20,7 +20,7 @@ void InitClock()
   print_time = TRUE;
 
   if (getitimer(ITIMER_REAL, &value)!= 0) {
-      sprintf(message,"getitimer() failed: %s", sys_errlist[errno]);
+      sprintf(message,"getitimer() failed: %s", strerror(errno));
       ERROR_MSG(message);
   }
   value.it_interval.tv_sec = CLOCK_INTERVAL;
@@ -28,7 +28,7 @@ void InitClock()
   value.it_interval.tv_usec = 0;
   
   if (setitimer(ITIMER_REAL, &value, &ovalue)!= 0) {
-      sprintf(message,"setitimer() failed: %s", sys_errlist[errno]);
+      sprintf(message,"setitimer() failed: %s", strerror(errno));
       ERROR_MSG(message);
   }
   ClockHandler(0);
