@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/config.h,v 1.20 2001/02/03 15:58:51 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/config.h,v 1.21 2001/06/15 16:36:36 werner Exp $
  *
  * Header-Datei fuer YTREE
  *
@@ -89,6 +89,26 @@
 #define DEFAULT_UNCOMPRESS "gunzip"
 #endif /* linux */
 
+#ifdef __GNU__
+#undef  DEFAULT_TARLIST
+#undef  DEFAULT_TAREXPAND
+#undef  DEFAULT_HEXDUMP
+#undef  DEFAULT_PAGER
+#undef  DEFAULT_LHALIST
+#undef  DEFAULT_LHAEXPAND
+#undef  DEFAULT_TAPEDEV
+#undef  DEFAULT_UNCOMPRESS
+#define DEFAULT_TARLIST    "tar tvf -"
+#define DEFAULT_TAREXPAND  "tar xOPf -"
+#define DEFAULT_HEXDUMP    "hexdump"
+#define DEFAULT_PAGER      "less"
+#define DEFAULT_LHALIST    "lharc v"
+#define DEFAULT_LHAEXPAND  "lharc p"
+#define DEFAULT_TAPEDEV    "/dev/rmt0"
+#define DEFAULT_UNCOMPRESS "gunzip"
+#endif /* __GNU__ */
+
+
 #ifdef __NeXT__
 /* fifi's NeXT! */
 # undef DEFAULT_TARLIST
