@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/dirwin.c,v 1.18 2000/07/13 18:26:06 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/dirwin.c,v 1.20 2001/04/16 13:34:26 werner Exp $
  *
  * Funktionen zur Handhabung des DIR-Windows
  *
@@ -66,7 +66,7 @@ static void RotateDirMode(void)
     case MODE_3: dir_mode = MODE_1 ; break;
     case MODE_4: dir_mode = MODE_3 ; break;
   }
-  if( (mode != DISK_MODE ) && 
+  if( (mode != DISK_MODE && mode != USER_MODE ) && 
       dir_mode == MODE_4 ) RotateDirMode();
 }
 
@@ -366,7 +366,7 @@ static void Movedown(int *disp_begin_pos, int *cursor_pos, DirEntry **dir_entry)
       (*dir_entry)->start_file = 0;
       (*dir_entry)->cursor_pos = -1;
       DisplayFileWindow( *dir_entry );
-      wnoutrefresh( file_window );
+      RefreshWindow( file_window );
    }
    return;
 }
@@ -422,7 +422,7 @@ static void Moveup(int *disp_begin_pos, int *cursor_pos, DirEntry **dir_entry)
       (*dir_entry)->start_file = 0;
       (*dir_entry)->cursor_pos = -1;
       DisplayFileWindow( *dir_entry );
-      wnoutrefresh( file_window );
+      RefreshWindow( file_window );
    }
    return;
 }
@@ -456,7 +456,7 @@ static void Movenpage(int *disp_begin_pos, int *cursor_pos, DirEntry **dir_entry
       	   (*dir_entry)->start_file = 0;
       	   (*dir_entry)->cursor_pos = -1;
            DisplayFileWindow( *dir_entry );
-           wnoutrefresh( file_window );
+           RefreshWindow( file_window );
            PrintDirEntry( dir_window,
                           *disp_begin_pos + *cursor_pos, 
                           *cursor_pos,
@@ -482,7 +482,7 @@ static void Movenpage(int *disp_begin_pos, int *cursor_pos, DirEntry **dir_entry
       	  (*dir_entry)->start_file = 0;
       	  (*dir_entry)->cursor_pos = -1;
           DisplayFileWindow( *dir_entry );
-          wnoutrefresh( file_window );
+          RefreshWindow( file_window );
           DisplayTree(dir_window,*disp_begin_pos,*disp_begin_pos+*cursor_pos);
       }
    }
@@ -514,7 +514,7 @@ static void Moveppage(int *disp_begin_pos, int *cursor_pos, DirEntry **dir_entry
       	   (*dir_entry)->start_file = 0;
       	   (*dir_entry)->cursor_pos = -1;
            DisplayFileWindow( *dir_entry );
-           wnoutrefresh( file_window );
+           RefreshWindow( file_window );
            PrintDirEntry( dir_window,
                           *disp_begin_pos + *cursor_pos, 
                           *cursor_pos,
@@ -534,7 +534,7 @@ static void Moveppage(int *disp_begin_pos, int *cursor_pos, DirEntry **dir_entry
       	 (*dir_entry)->start_file = 0;
       	 (*dir_entry)->cursor_pos = -1;
          DisplayFileWindow( *dir_entry );
-         wnoutrefresh( file_window );
+         RefreshWindow( file_window );
          DisplayTree(dir_window,*disp_begin_pos,*disp_begin_pos+*cursor_pos);
       } 
    }
@@ -550,6 +550,7 @@ int HandleDirWindow(DirEntry *start_dir_entry)
   BOOL need_dsp_help;
   char new_name[PATH_LENGTH + 1];
   char new_login_path[PATH_LENGTH + 1];
+  char *home;
 
   unput_char = 0;
 
@@ -563,7 +564,45 @@ int HandleDirWindow(DirEntry *start_dir_entry)
   need_dsp_help = TRUE;
 
   BuildDirEntryList( start_dir_entry );
-  
+  if ( initial_directory != NULL )
+  {
+    if ( !strcmp( initial_directory, "." ) )   /* Entry just a single "." */
+    {
+      statistic.disp_begin_pos = 0;
+      statistic.cursor_pos = 0;
+      unput_char = CR;
+    }
+    else
+    {
+      if ( *initial_directory == '.' ) {   /* Entry of form "./alpha/beta" */
+        strcpy( new_login_path, start_dir_entry->name );
+        strcat( new_login_path, initial_directory+1 );
+      }
+      else if ( *initial_directory == '~' && ( home = getenv("HOME") ) ) {
+                                           /* Entry of form "~/alpha/beta" */
+        strcpy( new_login_path, home );
+        strcat( new_login_path, initial_directory+1 );
+      }
+      else {            /* Entry of form "beta" or "/full/path/alpha/beta" */
+        strcpy(new_login_path, initial_directory);
+      }
+      for ( i = 0; i < statistic.disk_total_directories; i++ )
+      {
+        if ( *new_login_path == FILE_SEPARATOR_CHAR )
+          GetPath( dir_entry_list[i].dir_entry, new_name );
+        else
+          strcpy( new_name, dir_entry_list[i].dir_entry->name );
+        if ( !strcmp( new_login_path, new_name ) )
+        {
+          statistic.disp_begin_pos = i;
+          statistic.cursor_pos = 0;
+          unput_char = CR;
+          break;
+        }
+      }
+    }
+    initial_directory = NULL; 
+  }
   dir_entry = dir_entry_list[statistic.disp_begin_pos + statistic.cursor_pos].dir_entry;
  
   DisplayDiskStatistic();
@@ -573,13 +612,13 @@ int HandleDirWindow(DirEntry *start_dir_entry)
     dir_entry->cursor_pos = -1;
   }
   DisplayFileWindow( dir_entry );
-  wnoutrefresh( file_window );
+  RefreshWindow( file_window );
   DisplayTree( dir_window, statistic.disp_begin_pos, statistic.disp_begin_pos + statistic.cursor_pos );
   touchwin(dir_window);
 
   if( dir_entry->login_flag )
   {
-    if( dir_entry->global_flag )
+    if( (dir_entry->global_flag ) || (dir_entry->tagged_flag) )
     {
       unput_char = 'S';
     }
@@ -596,7 +635,7 @@ int HandleDirWindow(DirEntry *start_dir_entry)
       DisplayDirHelp();
     }
     DisplayDirParameter( dir_entry );
-    wnoutrefresh( dir_window );
+    RefreshWindow( dir_window );
     if( unput_char )
     {
       ch = unput_char;
@@ -634,6 +673,10 @@ int HandleDirWindow(DirEntry *start_dir_entry)
        resize_request = FALSE;
     }
 
+   if (mode == USER_MODE) { /* DirUserMode returns (possibly remapped) ch, or -1 if it handles ch */
+      ch = DirUserMode(dir_entry, ch);
+   }
+
     switch( ch )
     {
 
@@ -667,7 +710,7 @@ int HandleDirWindow(DirEntry *start_dir_entry)
 		       dir_entry->start_file = 0;
 		       dir_entry->cursor_pos = -1;
                        DisplayFileWindow( dir_entry );
-                       wnoutrefresh( file_window );
+                       RefreshWindow( file_window );
                        DisplayTree( dir_window, statistic.disp_begin_pos, 
 				    statistic.disp_begin_pos + statistic.cursor_pos 
 				  );
@@ -679,7 +722,7 @@ int HandleDirWindow(DirEntry *start_dir_entry)
 		     dir_entry->start_file = 0;
 		     dir_entry->cursor_pos = -1;
                      DisplayFileWindow( dir_entry );
-                     wnoutrefresh( file_window );
+                     RefreshWindow( file_window );
                      DisplayTree( dir_window, statistic.disp_begin_pos, 
 				  statistic.disp_begin_pos + statistic.cursor_pos 
 				);
@@ -736,7 +779,7 @@ int HandleDirWindow(DirEntry *start_dir_entry)
 		       dir_entry->start_file = 0;
 		       dir_entry->cursor_pos = -1;
                        DisplayFileWindow( dir_entry );
-                       wnoutrefresh( file_window );
+                       RefreshWindow( file_window );
 		       DisplayDiskStatistic();
 		     }
 		     need_dsp_help = TRUE;
@@ -759,7 +802,7 @@ int HandleDirWindow(DirEntry *start_dir_entry)
 		     dir_entry->start_file = 0;
 		     dir_entry->cursor_pos = -1;
                      DisplayFileWindow( dir_entry );
-                     wnoutrefresh( file_window );
+                     RefreshWindow( file_window );
 		     DisplayDiskStatistic();
 		     break;
 
@@ -781,7 +824,7 @@ int HandleDirWindow(DirEntry *start_dir_entry)
 		     dir_entry->start_file = 0;
 		     dir_entry->cursor_pos = -1;
                      DisplayFileWindow( dir_entry );
-                     wnoutrefresh( file_window );
+                     RefreshWindow( file_window );
 		     DisplayDiskStatistic();
 		     break;
       case 'T' & 0x1F :
@@ -808,7 +851,7 @@ int HandleDirWindow(DirEntry *start_dir_entry)
 		     dir_entry->start_file = 0;
 		     dir_entry->cursor_pos = -1;
                      DisplayFileWindow( dir_entry );
-                     wnoutrefresh( file_window );
+                     RefreshWindow( file_window );
 		     DisplayDiskStatistic();
 		     break;
       case 'U' & 0x1F :
@@ -835,7 +878,7 @@ int HandleDirWindow(DirEntry *start_dir_entry)
 		     dir_entry->start_file = 0;
 		     dir_entry->cursor_pos = -1;
                      DisplayFileWindow( dir_entry );
-                     wnoutrefresh( file_window );
+                     RefreshWindow( file_window );
 		     DisplayDiskStatistic();
 		     break;
       case 'F' & 0x1F : 
@@ -844,10 +887,52 @@ int HandleDirWindow(DirEntry *start_dir_entry)
                      DisplayTree( dir_window, statistic.disp_begin_pos, 
                                   statistic.disp_begin_pos + statistic.cursor_pos 
                                   );
-                     /*wnoutrefresh( file_window );*/
+                     /*RefreshWindow( file_window );*/
 		     DisplayDiskStatistic();
 		     need_dsp_help = TRUE;
 		     break;
+      case 'S' & 0x1F : 
+         	     if( statistic.disk_tagged_files )
+		     {
+    		       if(dir_entry->login_flag) {
+		         dir_entry->login_flag = FALSE;
+		       } else {
+		         dir_entry->big_window  = TRUE;
+                         dir_entry->global_flag = TRUE;
+		         dir_entry->tagged_flag = TRUE;
+		         dir_entry->start_file  = 0;
+		         dir_entry->cursor_pos  = 0;
+		       }
+		       if( HandleFileWindow(dir_entry) != LOGIN_ESC )
+		       {
+		         DisplayDiskStatistic();
+		         dir_entry->start_file = 0;
+		         dir_entry->cursor_pos = -1;
+                         DisplayFileWindow( dir_entry );
+                         RefreshWindow( small_file_window );
+                         RefreshWindow( big_file_window );
+		         BuildDirEntryList( start_dir_entry );
+                         DisplayTree( dir_window, statistic.disp_begin_pos, 
+				      statistic.disp_begin_pos + statistic.cursor_pos 
+				    );
+		       }
+		       else
+		       {
+		         BuildDirEntryList( statistic.tree );
+                         DisplayTree( dir_window, statistic.disp_begin_pos, 
+				      statistic.disp_begin_pos + statistic.cursor_pos 
+				    );
+			 ch = 'L';
+		       }
+		     }
+		     else
+		     {
+		       dir_entry->login_flag = FALSE;
+		       beep();
+		     }
+		     need_dsp_help = TRUE;
+		     break;
+
       case 'S':
       case 's':      if( statistic.disk_matching_files )
 		     {
@@ -866,8 +951,8 @@ int HandleDirWindow(DirEntry *start_dir_entry)
 		         dir_entry->start_file = 0;
 		         dir_entry->cursor_pos = -1;
                          DisplayFileWindow( dir_entry );
-                         wnoutrefresh( small_file_window );
-                         wnoutrefresh( big_file_window );
+                         RefreshWindow( small_file_window );
+                         RefreshWindow( big_file_window );
 		         BuildDirEntryList( start_dir_entry );
                          DisplayTree( dir_window, statistic.disp_begin_pos, 
 				      statistic.disp_begin_pos + statistic.cursor_pos 
@@ -896,6 +981,7 @@ int HandleDirWindow(DirEntry *start_dir_entry)
 		         dir_entry->login_flag = FALSE;
 		       } else {
 		         dir_entry->global_flag = FALSE;
+                         dir_entry->tagged_flag = FALSE;
 		         dir_entry->big_window  = bypass_small_window;
 		         dir_entry->start_file  = 0;
 		         dir_entry->cursor_pos  = 0;
@@ -906,8 +992,8 @@ int HandleDirWindow(DirEntry *start_dir_entry)
 		         dir_entry->start_file = 0;
 		         dir_entry->cursor_pos = -1;
 			 DisplayFileWindow( dir_entry );
-                         wnoutrefresh( small_file_window );
-                         wnoutrefresh( big_file_window );
+                         RefreshWindow( small_file_window );
+                         RefreshWindow( big_file_window );
 		         BuildDirEntryList( start_dir_entry );
                          DisplayTree( dir_window, statistic.disp_begin_pos, 
 				      statistic.disp_begin_pos + statistic.cursor_pos 
@@ -961,7 +1047,7 @@ int HandleDirWindow(DirEntry *start_dir_entry)
 		     dir_entry->start_file = 0;
 		     dir_entry->cursor_pos = -1;
                      DisplayFileWindow( dir_entry );
-                     wnoutrefresh( file_window );
+                     RefreshWindow( file_window );
 		     DisplayTree( dir_window, statistic.disp_begin_pos, 
 				  statistic.disp_begin_pos + statistic.cursor_pos 
 				);
@@ -1007,7 +1093,7 @@ int HandleDirWindow(DirEntry *start_dir_entry)
 #ifndef VI_KEYS
       case 'l':
 #endif /* VI_KEYS */
-      case 'L':      if( mode != DISK_MODE ) 
+      case 'L':      if( mode != DISK_MODE && mode != USER_MODE ) 
 		       (void) strcpy( new_login_path, disk_statistic.login_path );
 		     else
 		       (void) GetPath( dir_entry, new_login_path );
@@ -1071,7 +1157,7 @@ int KeyF2Get(DirEntry *start_dir_entry,
   DisplayTree( f2_window, disp_begin_pos, disp_begin_pos + cursor_pos );
   do
   {
-    wnoutrefresh( f2_window );
+    RefreshWindow( f2_window );
     doupdate();
     ch = Getch();
     GetMaxYX(f2_window, &win_height, &win_width);  /* Maybe changed... */
