@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/disp.c,v 1.16 2000/05/28 17:48:40 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/disp.c,v 1.18 2001/04/16 13:34:26 werner Exp $
  *
  * Menue-Geruest anzeigen
  *
@@ -59,11 +59,13 @@ static char *last_line = "3-8--------------------4";
 static char *first_line ="1-5";
 
 
+static char dir_help_disk_mode_0[] = "DIR       (A)ttribute (D)elete  (F)ilespec  (G)roup (L)og (M)akedir                 (Q)uit";
+static char dir_help_disk_mode_1[] = "COMMANDS  (O)wner (R)ename (S)howall (^S)how-tagged (T)ag (U)ntag e(X)ecute   (^F) dirmode"; 
 static char *dir_help[MAX_MODES][2] = 
   {
     { /* DISK_MODE */
-      "DIR       (A)ttribute (D)elete  (F)ilespec  (G)roup (L)og (M)akedir (Q)uit                ",
-      "COMMANDS  (O)wner (R)ename (S)howall (T)ag (U)ntag e(X)ecute   (^F) dirmode               "
+      dir_help_disk_mode_0,
+      dir_help_disk_mode_1
     },
     { /* LL_FILE_MODE */
       "DIR       (F)ilespec (L)ogin (S)howall (T)ag (U)ntag e(X)ecute   (^F) dirmode  (Q)uit       ",
@@ -100,15 +102,21 @@ static char *dir_help[MAX_MODES][2] =
     { /* TAPE_MODE */
       "TAPE-DIR  (F)ilespec (L)og (S)howall (T)ag (U)ntag e(X)ecute   (^F) dirmode  (Q)uit         ",
       "COMMANDS                                                                    "
+    },
+    { /* USER_MODE */
+      dir_help_disk_mode_0,	/* Default unless changed by user prefs */
+      dir_help_disk_mode_1
     }
   };
 
 
+static char file_help_disk_mode_0[] = "FILE      (A)ttribute (C)opy (D)elete (E)dit (F)ilespec (G)roup (H)ex (L)ogin (M)ove    (Q)uit ";
+static char file_help_disk_mode_1[] = "COMMANDS  (O)wner (P)ipe (R)ename (S)ort (T)ag (U)ntag (V)iew e(X)ecute pathcop(Y) (^F)ilemode ";
 static char *file_help[MAX_MODES][2] = 
   {
     { /* DISK_MODE */
-      "FILE      (A)ttribute (C)opy (D)elete (E)dit (F)ilespec (G)roup (H)ex (L)ogin (M)ove    (Q)uit ",
-      "COMMANDS  (O)wner (P)ipe (R)ename (S)ort (T)ag (U)ntag (V)iew e(X)ecute pathcop(Y) (^F)ilemode "
+      file_help_disk_mode_0,
+      file_help_disk_mode_1
     },
     { /* LL_FILE_MODE */
       "FILE      (F)ilespec (L)ogin (S)ort (T)ag (U)ntag e(X)ecute (^F)ilemode      (Q)uit        ",
@@ -145,6 +153,10 @@ static char *file_help[MAX_MODES][2] =
     { /* TAPE_MODE */
       "TAPE-FILE (C)opy (F)ilespec (H)ex (P)ipe (S)ort (T)ag (U)ntag (V)iew pathcop(Y) (Q)uit         ",
       "COMMANDS  (^F)ilemode                                                        "
+    },
+    { /* USER_MODE */
+      file_help_disk_mode_0,	/* Default unless changed by user prefs */
+      file_help_disk_mode_1
     }
   };
 
@@ -172,7 +184,14 @@ static void DisplayVersion(void)
 void DisplayDirHelp(void)
 {
   int i;
+  char *cptr;
 
+  if (mode == USER_MODE) {
+    if (dir_help[mode][0] == dir_help_disk_mode_0 && (cptr = DIR1) != NULL)
+      dir_help[mode][0] = cptr;
+    if (dir_help[mode][1] == dir_help_disk_mode_1 && (cptr = DIR2) != NULL)
+      dir_help[mode][1] = cptr;
+  }
   for( i=0; i < sizeof(dir_help[mode]) / sizeof(dir_help[mode][0]); i++) {
     PrintOptions( stdscr, LINES - 2 + i, 0, dir_help[mode][i] );
     clrtoeol();
@@ -184,7 +203,14 @@ void DisplayDirHelp(void)
 void DisplayFileHelp(void)
 {
   int i;
+  char *cptr;
 
+  if (mode == USER_MODE) {
+    if (file_help[mode][0] == file_help_disk_mode_0 && (cptr = FILE1) != NULL)
+      file_help[mode][0] = cptr;
+    if (file_help[mode][1] == file_help_disk_mode_1 && (cptr = FILE2) != NULL)
+      file_help[mode][1] = cptr;
+  }
   for( i=0; i < sizeof(file_help[mode]) / sizeof(file_help[mode][0]); i++) {
     PrintOptions( stdscr, LINES - 2 + i, 0, file_help[mode][i] );
     clrtoeol();
@@ -254,14 +280,14 @@ void SwitchToSmallFileWindow(void)
   werase( file_window );
   PrintLine( stdscr, DIR_WINDOW_HEIGHT + 2, 0, "6-7", COLS - 22 );
   file_window = small_file_window;
-  wnoutrefresh( stdscr );
+  RefreshWindow( stdscr );
 }
 
 
 void SwitchToBigFileWindow(void)
 {
   werase( file_window );
-  wnoutrefresh( file_window );
+  RefreshWindow( file_window );
 #ifdef COLOR_SUPPORT
   mvaddch(DIR_WINDOW_Y + DIR_WINDOW_HEIGHT, DIR_WINDOW_X - 1, 
         ACS_VLINE | COLOR_PAIR(MENU_COLOR)| A_BOLD);
@@ -279,7 +305,7 @@ void SwitchToBigFileWindow(void)
 	 );
 #endif /* COLOR_SUPPORT */
   file_window = big_file_window;
-  wnoutrefresh( stdscr );
+  RefreshWindow( stdscr );
 }
 
 
@@ -297,7 +323,7 @@ void MapF2Window(void)
   buffer[F2_WINDOW_WIDTH] = '\0';
 
   PrintSpecialString( f2_window, F2_WINDOW_HEIGHT - 1, 0, buffer, HST_COLOR );
-  wnoutrefresh( f2_window );
+  RefreshWindow( f2_window );
   free(buffer);
 }
 
@@ -380,3 +406,8 @@ static void PrintLine(WINDOW *win, int y, int x, char *line, int len)
   }
 }
 
+void RefreshWindow(WINDOW *win)
+{
+	wnoutrefresh(win);
+}
+	
