@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/edit.c,v 1.12 2001/02/03 15:58:51 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/edit.c,v 1.13 2001/06/15 16:36:36 werner Exp $
  *
  * Edit-Kommando-Bearbeitung
  *
@@ -29,7 +29,7 @@ int Edit(char *file_path)
     (void) sprintf( message, 
 		    "Edit not possible!*\"%s\"*%s", 
 		    file_path, 
-		    sys_errlist[errno] 
+		    strerror(errno) 
 		  );
     MESSAGE( message );
     ESCAPE;
