@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/filewin.c,v 1.25 2001/04/16 13:34:26 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/filewin.c,v 1.26 2001/06/15 16:36:36 werner Exp $
  *
  * Funktionen zur Handhabung des FILE-Windows
  *
@@ -339,11 +339,20 @@ static int SortByName(FileEntryList *e1, FileEntryList *e2)
 static int SortByExtension(FileEntryList *e1, FileEntryList *e2)
 {
   char *ext1, *ext2;
+  int cmp, casecmp;
 
   /* Ok, this isn't optimized */
 
   ext1 = GetExtension(e1->file->name);
   ext2 = GetExtension(e2->file->name);
+  cmp=strcmp( ext1, ext2 );
+  casecmp=strcasecmp( ext1, ext2 );
+
+  if (do_case && !cmp)
+      return SortByName( e1, e2 );
+  if (!do_case && !casecmp)
+      return SortByName( e1, e2 );
+
 
   if (do_case)
      if (order)
