@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/freesp.c,v 1.18 2001/02/03 15:58:51 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/freesp.c,v 1.19 2001/06/15 16:36:36 werner Exp $
  *
  * Ermittlung der freien Plattenkapazitaet
  *
@@ -9,7 +9,7 @@
 
 #include "ytree.h"
 
-#if ( defined( linux ) || defined( sun ) || defined( __NeXT__ )  || defined(hpux) || defined ( __FreeBSD__ ) || defined( __DJGPP__ ) ) && !defined( SVR4 )
+#if ( defined( linux ) || defined( sun ) || defined( __NeXT__ )  || defined(hpux) || defined ( __FreeBSD__ ) || defined( __DJGPP__ ) || defined ( __GNU__ ) ) && !defined( SVR4 )
 
 #include <sys/vfs.h>
 #else
@@ -35,7 +35,9 @@
 #endif /* WIN32 */
 #endif /* sun / linux / __NeXT__  hpux */
 
-
+#ifdef __GNU__
+#include <hurd/hurd_types.h>
+#endif
 
 
 
@@ -127,6 +129,66 @@ int GetDiskParameter( char *path,
 	       fname = "LINUX";
 	}
 #else
+#ifdef __GNU__
+       switch( statfs_struct.f_type ) {
+         case FSTYPE_UFS:
+              fname = "UFS"; break;
+         case FSTYPE_NFS:
+              fname = "NFS"; break;
+         case FSTYPE_GFS:
+              fname = "GFS"; break;
+         case FSTYPE_LFS:
+              fname = "LFS"; break;
+         case FSTYPE_SYSV:
+              fname = "SYSV"; break;
+         case FSTYPE_FTP:
+              fname = "FTP"; break;
+         case FSTYPE_TAR:
+              fname = "TAR"; break;
+         case FSTYPE_AR:
+              fname = "AR"; break;
+         case FSTYPE_CPIO:
+              fname = "CPIO"; break;
+         case FSTYPE_MSLOSS:
+              fname = "DOS"; break;
+         case FSTYPE_CPM:
+              fname = "CPM"; break;
+         case FSTYPE_HFS:
+              fname = "HFS"; break;
+         case FSTYPE_DTFS:
+              fname = "DTFS"; break;
+         case FSTYPE_GRFS:
+              fname = "GRFS"; break;
+         case FSTYPE_TERM:
+              fname = "TERM"; break;
+         case FSTYPE_DEV:
+              fname = "DEV"; break;
+         case FSTYPE_PROC:
+              fname = "PROC"; break;
+         case FSTYPE_IFSOCK:
+              fname = "IFSOCK"; break;
+         case FSTYPE_AFS:
+              fname = "AFS"; break;
+         case FSTYPE_DFS:
+              fname = "DFS"; break;
+         case FSTYPE_PROC9:
+              fname = "PROC9"; break;
+         case FSTYPE_SOCKET:
+              fname = "SOCKET"; break;
+         case FSTYPE_MISC:
+              fname = "MISC"; break;
+         case FSTYPE_EXT2FS:
+              fname = "EXT2FS"; break;
+         case FSTYPE_HTTP:
+              fname = "HTTP"; break;
+         case FSTYPE_MEMFS:
+              fname = "MEM"; break;
+         case FSTYPE_ISO9660:
+              fname = "ISO9660"; break;
+         default:
+              fname = "HURD";
+       }
+#else
 #if defined( sun56 ) || defined( sun ) || defined( hpux ) || defined( __NeXT__ ) || defined( ultrix ) || defined ( __FreeBSD__ )
         fname = "UNIX";
 #else
@@ -148,6 +210,7 @@ int GetDiskParameter( char *path,
 #endif /* QNX */
 #endif /* WIN32 */
 #endif /* sun / hpux / __NeXT__ ultrix */
+#endif /* __GNU__ */
 #endif /* linux */
 
         (void) strncpy( volume_name, 
@@ -183,7 +246,7 @@ int GetDiskParameter( char *path,
     *avail_bytes = bfree * statfs_struct.f_frsize;
     this_disk_space   = statfs_struct.f_blocks * statfs_struct.f_frsize;
 #else
-#if defined( _IBMR2 ) || defined( linux ) || defined( sun ) || defined( __NeXT__ )
+#if defined( _IBMR2 ) || defined( linux ) || defined( sun ) || defined( __NeXT__ ) || defined( __GNU__ )
     bfree = getuid() ? statfs_struct.f_bavail : statfs_struct.f_bfree;
     if( bfree < 0L ) bfree = 0L;
     *avail_bytes = bfree * statfs_struct.f_bsize;
@@ -211,7 +274,7 @@ int GetDiskParameter( char *path,
 #endif /* ultrix */
 #endif /* SVR3 */
 #endif /* SVR4/!__DGUX__ */
-#endif /* _IBMR2/linux/sun/__NeXT__ */
+#endif /* _IBMR2/linux/sun/__NeXT__/__GNU__ */
 #endif /* WIN32 */
     
     if( total_disk_space )
