@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/login.c,v 1.18 2001/04/16 13:34:26 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/login.c,v 1.19 2001/06/15 16:36:36 werner Exp $
  *
  * Dateibaum lesen
  *
@@ -99,7 +99,7 @@ int LoginDisk(char *path)
     /* Stat failed */
     /*-------------*/
 
-    (void) sprintf( message, "Can't access*\"%s\"*%s", path, sys_errlist[errno] );
+    (void) sprintf( message, "Can't access*\"%s\"*%s", path, strerror(errno) );
     MESSAGE( message );
     return( -1 );
   }
