@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/main.c,v 1.12 2000/07/13 18:26:06 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/main.c,v 1.13 2001/02/03 15:58:51 werner Exp $
  *
  * Hauptmodul
  *
@@ -19,15 +19,45 @@ static char path[PATH_LENGTH+1];
 int main(int argc, char **argv)
 {
   char *p;
+  int argi;
+  char *hist;
+  char *conf;
 
-  if (Init())
+  hist = NULL;
+  conf = NULL;
+  p = DEFAULT_TREE;
+  for (argi = 1; argi < argc; argi++)
+  {
+    if (*(argv[argi]) != '-')
+    {
+      p = argv[argi];
+      break;
+    }
+    switch(*(argv[argi]+1)) {
+    case 'p':
+    case 'P':
+      if (*(argv[argi]+2) <= ' ')
+        conf = argv[++argi];
+      else
+        conf = argv[argi]+2;
+      break;
+    case 'h':
+    case 'H':
+      if (*(argv[argi]+2) <= ' ')
+        hist = argv[++argi];
+      else
+        hist = argv[argi]+2;
+      break;
+    default:
+      printf("Usage: %s [-p profile_file] [-h hist_file] [initial_dir]\n",
+          argv[0]);
+      exit(1); 
+    }
+  }
+
+  if (Init(conf, hist))
       exit(1);
 
-  if( argc == 2 ) 
-    p = argv[1]; 
-  else 
-    p = DEFAULT_TREE;
-
   if( *p != FILE_SEPARATOR_CHAR )
   {
     /* rel. Pfad */
