@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/match.c,v 1.13 2001/04/16 13:34:26 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/match.c,v 1.14 2001/06/15 16:36:36 werner Exp $
  *
  * Behandlung reg. Ausdruecke fuer Dateinamen
  *
@@ -9,7 +9,7 @@
 
 #include "ytree.h"
 
-#if defined( bsd ) || defined( sun ) || defined( linux ) || defined( __NeXT__ ) || defined( OSF1 ) || defined( __FreeBSD__ )
+#if defined( bsd ) || defined( sun ) || defined( linux ) || defined( __NeXT__ ) || defined( OSF1 ) || defined( __FreeBSD__ ) || defined( __GNU__ )
 #define HAS_REGEX
 #endif
 
