@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/move.c,v 1.11 2000/05/20 20:41:11 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/move.c,v 1.12 2001/06/15 16:36:36 werner Exp $
  *
  * Beschreibung : Bewegen von Dateien
  *
@@ -58,7 +58,7 @@ int MoveFile(FileEntry *fe_ptr,
     (void) sprintf( message, 
 		    "Unmoveable file*\"%s\"*%s", 
 		    from_path, 
-		    sys_errlist[errno] 
+		    strerror(errno) 
 		  );
     MESSAGE( message );
     ESCAPE;
@@ -109,7 +109,7 @@ int MoveFile(FileEntry *fe_ptr,
         (void) sprintf( message, 
 		        "Can't unlink*\"%s\"*%s", 
 		        to_path, 
-		        sys_errlist[errno] 
+		        strerror(errno) 
 		      );
         MESSAGE( message );
         ESCAPE;
@@ -251,7 +251,7 @@ static int Move(char *to_path, char *from_path)
 		    "Can't link \"%s\"*to \"%s\"*%s", 
 		    from_path, 
 		    to_path, 
-		    sys_errlist[errno] 
+		    strerror(errno) 
 		  );
     MESSAGE( message );
     return( -1 );
@@ -262,7 +262,7 @@ static int Move(char *to_path, char *from_path)
     (void) sprintf( message, 
 		    "Can't unlink*\"%s\"*%s", 
 		    from_path, 
-		    sys_errlist[errno] 
+		    strerror(errno) 
 		  );
     MESSAGE( message );
     return( -1 );
