@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/pipe.c,v 1.12 2001/02/03 15:58:51 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/pipe.c,v 1.13 2001/06/15 16:36:36 werner Exp $
  *
  * Umlenken von Datei-Inhalten zu einem Kommando
  *
@@ -133,7 +133,7 @@ int PipeTaggedFiles(FileEntry *fe_ptr, WalkingPackage *walking_package)
     (void) sprintf( message, 
 		    "Can't open file*\"%s\"*%s", 
 		    from_path, 
-		    sys_errlist[errno] 
+		    strerror(errno) 
 		  );
     MESSAGE( message );
     return( -1 );
@@ -147,7 +147,7 @@ int PipeTaggedFiles(FileEntry *fe_ptr, WalkingPackage *walking_package)
 		walking_package->function_data.pipe_cmd.pipe_file ) != 1 
       )
     {
-      (void) sprintf( message, "Write-Error!*%s", sys_errlist[errno] );
+      (void) sprintf( message, "Write-Error!*%s", strerror(errno) );
       MESSAGE( message );
       (void) close( i ); 
       return( -1 );
