@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /home/werner/ytree/RCS/quit.c,v 1.11 1998/11/11 19:02:48 werner Rel $
+ * $Header: /usr/local/cvsroot/utils/ytree/quit.c,v 1.12 2000/07/13 18:26:06 werner Exp $
  *
  * Verlassen von ytree
  *
@@ -30,6 +30,9 @@ void Quit(void)
       SaveHistory(path);
     }
     endwin();
+#ifdef XCURSES
+    XCursesExit();
+#endif
     exit( 0 );
   }
 }
