@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/stat.c,v 1.14 2000/07/13 18:26:06 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/stat.c,v 1.15 2001/04/16 13:34:26 werner Exp $
  *
  * Statistik-Modul
  *
@@ -40,7 +40,7 @@ void DisplayDiskStatistic(void)
 void DisplayAvailBytes(void)
 {
   PrettyPrintNumber( 6,  COLS - 14, statistic.disk_space / (LONGLONG)1024 );
-  wnoutrefresh( stdscr );
+  RefreshWindow( stdscr );
 }
 
 
@@ -49,7 +49,7 @@ void DisplayAvailBytes(void)
 void DisplayFileSpec(void)
 {
   mvwprintw( stdscr, 2,  COLS - 15, "%-14s", statistic.file_spec );
-  wnoutrefresh( stdscr );
+  RefreshWindow( stdscr );
 }
 
 
@@ -60,7 +60,7 @@ void DisplayDiskName(void)
   
   sprintf( buff, fmt, statistic.disk_name);
   PrintMenuOptions( stdscr, 4, COLS - 15, buff, MENU_COLOR, HIMENUS_COLOR);
-  wnoutrefresh( stdscr );
+  RefreshWindow( stdscr );
 }
 
 
@@ -87,7 +87,7 @@ void DisplayDirStatistic(DirEntry *dir_entry)
   PrettyPrintNumber( 16, COLS - 14, dir_entry->tagged_files );
   PrettyPrintNumber( 17, COLS - 14, dir_entry->tagged_bytes );
   PrintOptions( stdscr, 18, COLS - 21, "[Current File     ]" );
-  wnoutrefresh( stdscr );
+  RefreshWindow( stdscr );
   return;
 }
 
@@ -100,7 +100,7 @@ void DisplayDirTagged(DirEntry *dir_entry)
   PrettyPrintNumber( 16, COLS - 14, dir_entry->tagged_files );
   PrettyPrintNumber( 17, COLS - 14, dir_entry->tagged_bytes );
   
-  wnoutrefresh( stdscr );
+  RefreshWindow( stdscr );
 }
 
 
@@ -110,7 +110,7 @@ void DisplayDiskTagged(void)
   PrettyPrintNumber( 16, COLS - 14, statistic.disk_tagged_files );
   PrettyPrintNumber( 17, COLS - 14, statistic.disk_tagged_bytes );
   
-  wnoutrefresh( stdscr );
+  RefreshWindow( stdscr );
 }
 
 
@@ -137,7 +137,7 @@ void DisplayDirParameter(DirEntry *dir_entry)
   sprintf(auxbuff, "[%-17s]", CutFilename(buffer, f, 17));
   PrintMenuOptions( stdscr, 19, COLS - 19, auxbuff, MENU_COLOR, HIMENUS_COLOR);
   PrettyPrintNumber( 20, COLS - 14, (LONGLONG) dir_entry->total_bytes );
-  wnoutrefresh( stdscr );
+  RefreshWindow( stdscr );
 }
 
 
@@ -160,7 +160,7 @@ void DisplayGlobalFileParameter(FileEntry *file_entry)
   sprintf( buffer2, "[%-17s]", buffer1 );
   PrintMenuOptions( stdscr, 19, COLS - 19, buffer2, GLOBAL_COLOR, HIGLOBAL_COLOR);
   PrettyPrintNumber( 20, COLS - 14, (LONGLONG) file_entry->stat_struct.st_size );
-  wnoutrefresh( stdscr );
+  RefreshWindow( stdscr );
 }
 
 
@@ -173,7 +173,7 @@ void DisplayFileParameter(FileEntry *file_entry)
   sprintf( auxbuff, "[%-17s]", CutFilename( buffer, file_entry->name, 17 ) );
   PrintMenuOptions( stdscr, 19, COLS - 19, auxbuff, MENU_COLOR, HIMENUS_COLOR);
   PrettyPrintNumber( 20, COLS - 14, (LONGLONG)file_entry->stat_struct.st_size );
-  wnoutrefresh( stdscr );
+  RefreshWindow( stdscr );
 }
 
 
@@ -190,18 +190,22 @@ void PrettyPrintNumber(int y, int x, LONGLONG number)
   one      = (long) ( number % (LONGLONG) 1000 );
 
   if( billion ){
-     sprintf( buffer, "[%2ld%03ld%03ld%03ld]", billion, million, thousand, one);
+     /* "123123123123" */
+     sprintf( buffer, "[%3ld%03ld%03ld%03ld]", billion, million, thousand, one);
      PrintMenuOptions( stdscr, y, x, buffer, MENU_COLOR, HIMENUS_COLOR);
      }
   else if( million ) {
+     /* " 123,123,123" */
      sprintf( buffer, "[ %3ld%c%03ld%c%03ld]", million, number_seperator, thousand, number_seperator, one);
      PrintMenuOptions( stdscr, y, x, buffer, MENU_COLOR, HIMENUS_COLOR);
      }
   else if( thousand ) {
+     /* "     123,123" */
      sprintf( buffer, "[     %3ld%c%03ld]", thousand, number_seperator, one);
      PrintMenuOptions( stdscr, y, x, buffer, MENU_COLOR, HIMENUS_COLOR);
      }
   else {
+     /* "         123" */
      sprintf( buffer, "[         %3ld]", one);
      PrintMenuOptions( stdscr, y, x, buffer, MENU_COLOR, HIMENUS_COLOR);
      }
