@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /home/werner/ytree/RCS/system.c,v 1.8 1997/08/13 12:24:58 werner Rel $
+ * $Header: /usr/local/cvsroot/utils/ytree/system.c,v 1.10 2000/07/13 18:26:06 werner Exp $
  *
  * System Call
  *
@@ -16,7 +16,9 @@ int SystemCall(char *command_line)
 {
   int result;
 
+#ifndef XCURSES
   endwin();
+#endif
   result = SilentSystemCall( command_line );
   
   (void) GetAvailBytes( &statistic.disk_space );
@@ -29,7 +31,9 @@ int QuerySystemCall(char *command_line)
 {
   int result;
 
+#ifndef XCURSES
   endwin();
+#endif
   result = SilentSystemCall( command_line );
   HitReturnToContinue();
   (void) GetAvailBytes( &statistic.disk_space );
@@ -44,6 +48,9 @@ extern struct itimerval value, ovalue;
 int SilentSystemCall(char *command_line)
 {
   int result;
+#ifdef XCURSES
+  char *xterm=NULL;
+#endif
 
 #ifdef CLOCK_SUPPORT
   struct itimerval value, ovalue;
@@ -64,20 +71,33 @@ int SilentSystemCall(char *command_line)
   signal(SIGALRM, SIG_IGN);
 #endif
 
+#ifdef XCURSES
+  if( ( xterm = malloc( strlen( command_line ) + 10 ) ) == NULL ) {
+    ERROR_MSG( "Malloc Failed*ABORT" );
+    exit( 1 );
+  }
+  sprintf(xterm, "xterm -e %s &", command_line);
+  result = system( xterm );
+  free(xterm);
+#else
   result = system( command_line );
+#endif
 
 #ifdef CLOCK_SUPPORT
   setitimer(ITIMER_REAL, &ovalue, &value);
   signal(SIGALRM, ClockHandler);
 #endif
 
+#ifndef XCURSES
   leaveok(stdscr, TRUE);
+  curs_set(0);
 #if defined( __NeXT__ )
   cbreak();
   nonl();
   noecho();
   clearok( stdscr, TRUE );
 #endif /* linux */ 
+#endif /* XCURSES */
   
   return( result ); 
 }
