@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/util.c,v 1.25 2001/04/16 13:34:27 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/util.c,v 1.26 2001/06/15 16:36:36 werner Exp $
  *
  * Diverse Hilfsfunktionen
  *
@@ -106,7 +106,7 @@ int GetDirEntry(DirEntry *tree,
    strcpy(to_path, dir_path);
   if( getcwd( current_path, sizeof( current_path ) - 2 ) == NULL )
   {
-    (void) sprintf( message, "getcwd failed*%s", sys_errlist[errno] );
+    (void) sprintf( message, "getcwd failed*%s", strerror(errno) );
     ERROR_MSG( message );
     return( -1 );
   }
@@ -1358,3 +1358,21 @@ int Getch()
   return(c);
 }
 
+
+
+#ifndef HAVE_STRERROR
+const char *StrError(int errnum)
+{
+
+#if !defined(__FreeBSD__) && !(defined(__GLIBC__) && __GLIBC__ >= 2)
+  extern char *sys_errlist[];
+  extern int sys_nerr;
+#endif
+
+  if (errnum > 0 && errnum <= sys_nerr)
+    return(sys_errlist[errnum]);
+  return ("Unknown system error");
+}
+#endif /* HAVE_STRERROR */
+
+
