@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/ytree.h,v 1.28 2001/04/16 13:34:27 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/ytree.h,v 1.29 2001/06/15 16:36:36 werner Exp $
  *
  * Header-Datei fuer YTREE
  *
@@ -44,7 +44,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <time.h>
-#ifdef linux
+#if defined(linux) || defined(__GNU__)
 #include <sys/wait.h>
 #include <sys/time.h>	/* needed vor RedHed5 (thanks to Robert Spier) */
 #endif
@@ -102,7 +102,12 @@ extern char *getcwd();
 #define LONGLONG		long long
 #define HAS_LONGLONG		1
 #else
-#ifdef linux
+#if defined(linux)
+#define STATFS(a, b, c, d )     statfs( a, b )
+#define LONGLONG               long long
+#define HAS_LONGLONG           1
+#else
+#if defined(__GNU__)
 #define STATFS(a, b, c, d )     statfs( a, b )
 #define LONGLONG		long long
 #define HAS_LONGLONG		1
@@ -128,6 +133,7 @@ extern char *getcwd();
 #endif /* __QNX__ */
 #endif /* ultrix */
 #endif /* hpux */
+#endif /* __GNU__ */
 #endif /* linux */
 #endif /* _IBMR2 */
 #endif /* SVR4 */
@@ -172,9 +178,9 @@ extern char *getcwd();
 #endif /* __NeXT__ */
 
 
-#ifdef linux
+#if defined(linux) || defined (__GNU__)
 #define HAVE_RENAME
-#endif /* linux */
+#endif /* linux || __GNU__ */
 
 
 
@@ -822,11 +828,13 @@ typedef struct
   FunctionData  function_data;
 } WalkingPackage;
 
+/* strerror() is POSIX, and all modern operating systems provide it.  */
+#define HAVE_STRERROR 1
 
+#ifndef HAVE_STRERROR
+extern const char *StrError(int);
+#endif /* HAVE_STRERROR */
 
-#if !defined(__FreeBSD__) && !(defined(__GLIBC__) && __GLIBC__ >= 2)
-extern char *sys_errlist[];
-#endif
 
 extern WINDOW *dir_window;
 extern WINDOW *small_file_window;
